OpenSubdiv_v3_7_0_Bfr_SurfaceFactoryCacheThreaded

Struct OpenSubdiv_v3_7_0_Bfr_SurfaceFactoryCacheThreaded 

#[repr(C)]
pub struct OpenSubdiv_v3_7_0_Bfr_SurfaceFactoryCacheThreaded<MUTEX_TYPE> { pub _phantom_0: PhantomData<UnsafeCell<MUTEX_TYPE>>, pub _base: OpenSubdiv_v3_7_0_Bfr_SurfaceFactoryCache, pub _mutex: MUTEX_TYPE, }
@brief Template for declaring thread-safe subclasses of SurfaceFactoryCache

SurfaceFactoryCacheThreaded extends SurfaceFactoryCache by protecting access to the cache to ensure thread-safe operation. A mutex type and associated locks are specified to declare a subclass with appropriately protected read and write access.

@tparam MUTEX_TYPE A mutex type with supported lock guards @tparam READ_LOCK_GUARD_TYPE A scoped lock guard allowing potentially shared access for read operations. @tparam WRITE_LOCK_GUARD_TYPE A scoped lock guard allowing exclusive access for write operations.

Fields

_phantom_0: PhantomData<UnsafeCell<MUTEX_TYPE>>_base: OpenSubdiv_v3_7_0_Bfr_SurfaceFactoryCache_mutex: MUTEX_TYPE

@endcond PROTECTED